package eu.jonahbauer.wizard.client.libgdx.screens.eventscreens;

import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.HorizontalGroup;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;
import eu.jonahbauer.wizard.client.libgdx.screens.MenuScreen;
import eu.jonahbauer.wizard.common.messages.client.InteractionMessage;
import eu.jonahbauer.wizard.common.messages.player.PredictMessage;

import java.util.Map;
import java.util.UUID;

import static com.badlogic.gdx.scenes.scene2d.actions.Actions.removeActor;
import static com.badlogic.gdx.scenes.scene2d.actions.Actions.run;

public class ChangePredictionScreen extends EventScreen {

    final int round;
    final UUID player;
    final Map<UUID, Integer> predictions;
    public ChangePredictionScreen(MenuScreen.Data data, int round, UUID player, Map<UUID, Integer> predictions) {
        super(data);
        this.round = round;
        this.player = player;
        this.predictions = predictions;
        var labelTop = new Label("One of your tricks contains the Card Cloud.", data.skin);
        labelTop.setFontScale(2.0f);
        group.addActor(labelTop);
        showEventScreen();
    }

    @Override
    public void showEventScreen() {

        ChangeListener changeListener = new ChangeListener() {
            @Override
            public void changed(ChangeEvent event, Actor actor) {
                if(actor instanceof  TextButton textButton) {
                    int chosenPrediction = Integer.parseInt(textButton.getText().toString());
                    //Nur zur Demo - eigtl. Senden von predictMessage und Auswerten vin predictionMessage
                    predictions.put(player, Integer.parseInt(textButton.getText().toString()));
                    data.stage.addAction(removeActor(screen));
                    new InteractionMessage(new PredictMessage(chosenPrediction));
                }
            }
        };

        if (predictions.get(player) != null) {
            int i = predictions.get(player);
            var labelZeroPrediction = new Label("Your original prediction is", data.skin);
            labelZeroPrediction.setFontScale(2.0f);
            group.addActor(labelZeroPrediction);
            var originalPrediction = new Label(i + "", data.skin, "enchanted");
            group.addActor(originalPrediction);
            var labelPredictionUpper = new Label("According to the game rules your prediction", data.skin);
            labelPredictionUpper.setFontScale(2.0f);
            group.addActor(labelPredictionUpper);
            if (i == 0 || i == round) {
                var labelPredictionLower = new Label("must " + (i == 0 ? "increase" : "decrease") + " by one to", data.skin);
                labelPredictionLower.setFontScale(2.0f);
                group.addActor(labelPredictionLower);
                var newPrediction = new Label((i == 0 ? (i + 1) : (i - 1)) + "", data.skin, "enchanted");
                group.addActor(newPrediction);
                var okButton = new TextButton("OK", data.skin);
                okButton.addListener(
                        new ChangeListener() {
                            @Override
                            public void changed(ChangeEvent event, Actor actor) {
                                data.stage.addAction(removeActor(screen));
                            }
                        }
                );
                group.addActor(okButton);
                screen.addActor(group);
                if (i == 0) {
                    //nur Demo
                    predictions.put(player, ++i);
                    //eigtl.
                    new InteractionMessage(new PredictMessage(i));
                } else {
                    //nur Demo
                    predictions.put(player, --i);
                    //eigtl.
                    new InteractionMessage(new PredictMessage(i));
                }
            } else {
                var labelPredictionMiddle = new Label("must increase or decrease by one.", data.skin);
                labelPredictionMiddle.setFontScale(2.0f);
                group.addActor(labelPredictionMiddle);
                var labelPredictionLower = new Label("Please choose one of these two options", data.skin);
                labelPredictionLower.setFontScale(2.0f);
                group.addActor(labelPredictionLower);
                var horizontalGroup = new HorizontalGroup();
                horizontalGroup.space(50.0f);
                var decreaseButton = new TextButton((i - 1) + "", data.skin);
                var increaseButton = new TextButton((i + 1) + "", data.skin);
                decreaseButton.addListener(changeListener);
                increaseButton.addListener(changeListener);
                horizontalGroup.addActor(decreaseButton);
                horizontalGroup.addActor(increaseButton);
                group.addActor(horizontalGroup);
                screen.addActor(group);
            }
            data.stage.addAction(run(() -> data.stage.addActor(screen)));
        }
    }
}

