package eu.jonahbauer.wizard.client.libgdx.screens.eventscreens;

import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.math.Interpolation;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.HorizontalGroup;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.ui.VerticalGroup;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;
import com.badlogic.gdx.utils.Align;
import eu.jonahbauer.wizard.client.libgdx.actors.game.CardActor;
import eu.jonahbauer.wizard.client.libgdx.screens.MenuScreen;
import eu.jonahbauer.wizard.common.messages.client.InteractionMessage;
import eu.jonahbauer.wizard.common.messages.player.PickTrumpMessage;
import eu.jonahbauer.wizard.common.model.Card;

import static com.badlogic.gdx.scenes.scene2d.actions.Actions.*;

public class ChooseTrumpScreen extends EventScreen {

    private CardActor trumpCardActor;
    private Card trumpCard;
    private TextureAtlas atlas;
    public ChooseTrumpScreen(MenuScreen.Data data, CardActor trumpCardActor, Card trumpCard, TextureAtlas atlas) {
        super(data);
        this.trumpCardActor = trumpCardActor;
        this.trumpCard = trumpCard;
        this.atlas = atlas;
        showEventScreen();
    }

    @Override
    public void showEventScreen() {
        BitmapFont font = data.skin.getFont("default-font");
        font.getData().setScale(1.5f);

        var verticalGroup = new VerticalGroup().align(Align.center);
        screen.add(verticalGroup);

        var labelTop = new Label("The determined Trump Card Actor is: ", data.skin);
        verticalGroup.addActor(labelTop);
        verticalGroup.addActor(trumpCardActor);

        var labelMiddle = new Label("Please choose a Trump Color", data.skin);
        var horizontalGroupBottom = new HorizontalGroup();
        horizontalGroupBottom.space(40.0f);
        horizontalGroupBottom.padTop(30.0f);
        font.getData().setScale(2.5f);
        var chooseGreen = new TextButton("Green", data.skin, "toggle");
        chooseGreen.setColor(Card.Suit.GREEN.getRed(), Card.Suit.GREEN.getGreen(), Card.Suit.GREEN.getBlue(),Card.Suit.GREEN.getAlpha());
        horizontalGroupBottom.addActor(chooseGreen);
        var chooseBlue = new TextButton("Blue", data.skin, "toggle");
        chooseBlue.setColor(Card.Suit.BLUE.getRed(), Card.Suit.BLUE.getGreen(), Card.Suit.BLUE.getBlue(),Card.Suit.BLUE.getAlpha());
        horizontalGroupBottom.addActor(chooseBlue);
        var chooseYellow = new TextButton("Yellow", data.skin, "toggle");
        chooseYellow.setColor(Card.Suit.YELLOW.getRed(), Card.Suit.YELLOW.getGreen(), Card.Suit.YELLOW.getBlue(),Card.Suit.YELLOW.getAlpha());
        horizontalGroupBottom.addActor(chooseYellow);
        var chooseRed = new TextButton("Red", data.skin, "toggle");
        chooseRed.setColor(Card.Suit.RED.getRed(), Card.Suit.RED.getGreen(), Card.Suit.RED.getBlue(),Card.Suit.RED.getAlpha());
        horizontalGroupBottom.addActor(chooseRed);
        if(trumpCard == Card.WEREWOLF) {
            var chooseNone = new Label("Kein Trumpf", data.skin);
            chooseNone.setColor(Card.Suit.NONE.getRed(), Card.Suit.NONE.getGreen(), Card.Suit.NONE.getBlue(),Card.Suit.NONE.getAlpha());
            horizontalGroupBottom.addActor(chooseNone);
        }
        verticalGroup.addActor(labelMiddle);
        verticalGroup.addActor(horizontalGroupBottom);

        var chosenLabel = new Label("Sie haben gewählt", data.skin);

        ChangeListener changeListener = new ChangeListener() {
            @Override
            public void changed(ChangeEvent event, Actor actor) {
                Card.Suit suit;
                if(actor instanceof TextButton textButton) {
                    switch (textButton.getLabel().getText().toString()) {
                        //TODO - Eigene Karte nur mit Trumpfarbe? - Karte für keinen Trumpf?
                        //trumpCardActor.setCard(Card.values()[Card.XY.ordinal()]);
                        case "Green" -> {
                            trumpCardActor.setCard(Card.values()[0]);
                            suit = Card.Suit.GREEN;
                        }
                        case "Yellow" -> {
                            trumpCardActor.setCard(Card.values()[1]);
                            suit = Card.Suit.YELLOW;
                        }
                        case "Blue" -> {
                            trumpCardActor.setCard(Card.values()[2]);
                            suit = Card.Suit.BLUE;
                        }
                        case "Red" -> {
                            trumpCardActor.setCard(Card.values()[3]);
                            suit = Card.Suit.RED;
                        }
                        case "None" -> {
                            trumpCardActor.setCard(Card.values()[4]);
                            suit = Card.Suit.NONE;
                        }
                        default -> throw new AssertionError();
                    }
                    data.stage.addAction(sequence(
                            removeActor(horizontalGroupBottom),
                            removeActor(labelMiddle),
                            removeActor(labelTop),
                            run(() -> verticalGroup.addActorAt(0, chosenLabel)),
                            delay(2.0f),
                            removeActor(chosenLabel),
                            addAction(moveTo(10,10, 0.25f), trumpCardActor),
                            delay(.1f),
                            addAction(alpha(0.0f, .1f, Interpolation.pow2Out), background),
                            delay(.1f),
                            run(() -> data.stage.addActor(trumpCardActor)),
                            removeActor(screen)));

                    new InteractionMessage(new PickTrumpMessage(suit));
                }
            }
        };
        horizontalGroupBottom.addListener(changeListener);
        data.stage.addAction(run(() -> data.stage.addActor(screen)));
    }
}
