package eu.jonahbauer.wizard.client.libgdx.screens.eventscreens;

import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.math.Interpolation;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import eu.jonahbauer.wizard.client.libgdx.actors.game.CardActor;
import eu.jonahbauer.wizard.client.libgdx.screens.MenuScreen;
import eu.jonahbauer.wizard.common.model.Card;

import java.util.Map;
import java.util.UUID;

import static com.badlogic.gdx.scenes.scene2d.actions.Actions.*;

public class ChosenTrumpByOtherScreen extends EventScreen {

    private final UUID player;
    private final Map<UUID, String> names;
    private final Card.Suit suit;
    private CardActor trumpCardActor;
    private final TextureAtlas atlas;
    public ChosenTrumpByOtherScreen(MenuScreen.Data data, UUID player, Map<UUID, String> names, Card.Suit suit,
                                    CardActor trumpCardActor, TextureAtlas atlas) {
        super(data);
        this.player = player;
        this.names = names;
        this.suit = suit;
        this.trumpCardActor = trumpCardActor;
        this.atlas = atlas;
        showEventScreen();
    }

    @Override
    public void showEventScreen() {
        var playerName = new Label(names.get(player) + " has chosen the trump color: ", data.skin);
        playerName.setFontScale(1.5f);
        group.addActor(playerName);
        Label colorLabel;
        switch (suit) {
            case GREEN -> {
                colorLabel = new Label(Card.Suit.GREEN.toString(), data.skin);
                colorLabel.setColor(Card.Suit.GREEN.getRed(), Card.Suit.GREEN.getGreen(), Card.Suit.GREEN.getBlue(),Card.Suit.GREEN.getAlpha());
            }
            case BLUE -> {
                colorLabel = new Label(Card.Suit.BLUE.toString(), data.skin);
                colorLabel.setColor(Card.Suit.BLUE.getRed(), Card.Suit.BLUE.getGreen(), Card.Suit.BLUE.getBlue(),Card.Suit.BLUE.getAlpha());
            }
            case YELLOW -> {
                colorLabel = new Label(Card.Suit.YELLOW.toString(), data.skin);
                colorLabel.setColor(Card.Suit.YELLOW.getRed(), Card.Suit.YELLOW.getGreen(), Card.Suit.YELLOW.getBlue(),Card.Suit.YELLOW.getAlpha());
            }
            case RED -> {
                colorLabel = new Label(Card.Suit.RED.toString(), data.skin);
                colorLabel.setColor(Card.Suit.RED.getRed(), Card.Suit.RED.getGreen(), Card.Suit.RED.getBlue(),Card.Suit.RED.getAlpha());
            }
            case NONE -> {
                colorLabel = new Label(Card.Suit.NONE.toString(), data.skin);
                colorLabel.setColor(Card.Suit.NONE.getRed(), Card.Suit.NONE.getGreen(), Card.Suit.NONE.getBlue(),Card.Suit.NONE.getAlpha());
            }
            default -> throw new AssertionError();
        }
        group.addActor(colorLabel);

        //TODO - Bild/Region für ausgewählte Farbe
        //Card trumpCard = Card.values()[suit.ordinal()];
        //trumpCardActor.setCard(Card.values()[suit.ordinal()]);
        Card trumpCard = Card.BLUE_1;

        if (trumpCardActor != null) {
            trumpCardActor.setCard(trumpCard);
        } else {
            trumpCardActor = new CardActor(trumpCard, atlas);
        }

        group.addActor(trumpCardActor);
        screen.addActor(group);

        data.stage.addAction(sequence(
                run(() -> data.stage.addActor(screen)),
                delay(2.0f),
                removeActor(playerName),
                removeActor(colorLabel),
                addAction(moveTo(10,10, 0.25f), trumpCardActor),
                delay(.1f),
                addAction(alpha(0.0f, .1f, Interpolation.pow2Out), background),
                delay(.1f),
                run(() -> data.stage.addActor(trumpCardActor)),
                removeActor(screen)
        ));
    }
}
